// Generated by xsd compiler for ios/objective-c
// DO NOT CHANGE!

#import <Foundation/Foundation.h>

/**
 @file
 
 Enumerated type that contains the explanations for a buyer or seller opening a case
 against one another. These values are specified in the <b>DisputeExplanation</b>
 field of <b>AddDispute</b>, and are returned in the
 <b>GetUserDisputes</b> and <b>GetDispute</b> calls. The
 <b>DisputeReason</b> value will dictate what
 <b>DisputeExplanation</b> values that can be used/returned.
 
 
 @ingroup EBayAPIInterface
*/

/**
 
 This value indicates that the buyer has not paid for the order line item, and has
 not responded to the seller regarding payment. This value is allowed when the
 <b>DisputeReason</b> value is <b>BuyerHasNotPaid</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_BUYER_HAS_NOT_RESPONDED;

/**
 
 This value indicates that the buyer has not paid for the order line item, and
 according to the seller, has refused to pay for the order line item. This value is
 allowed when the <b>DisputeReason</b> value is
 <b>BuyerHasNotPaid</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_BUYER_REFUSED_TO_PAY;

/**
 
 This value indicates that the buyer has not paid for the order line item, and
 is not cleared by eBay to pay. This value is allowed when the
 <b>DisputeReason</b> value is
 <b>BuyerHasNotPaid</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_BUYER_NOT_CLEARED_TO_PAY;

/**
 
 This value indicates that the buyer has returned the item, and seller has agreed to
 cancel the order and issue a refund to the buyer. This value is allowed when the
 <b>DisputeReason</b> value is <b>TransactionMutuallyCanceled</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_BUYER_RETURNED_ITEM_FOR_REFUND;

/**
 
 This value indicates that the buyer and seller were unable to resolve a disagreement
 over terms, and the seller is willing to cancel the order line item. This value is allowed when the
 <b>DisputeReason</b> value is <b>TransactionMutuallyCanceled</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_UNABLE_TO_RESOLVE_TERMS;

/**
 
 This value indicates that the buyer no longer wants the item (buyer remorse), and
 the seller is willing to cancel the order line item. This value is allowed when the
 <b>DisputeReason</b> value is
 <b>TransactionMutuallyCanceled</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_BUYER_NO_LONGER_WANTS_ITEM;

/**
 
 This value indicates that the buyer made a mistake by purchasing the item, and
 the seller is willing to cancel the order line item. This value is allowed when the
 <b>DisputeReason</b> value is
 <b>TransactionMutuallyCanceled</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_BUYER_PURCHASING_MISTAKE;

/**
 
 This value is deprecated, and should not be used.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_SHIP_COUNTRY_NOT_SUPPORTED;

/**
 
 This value indicates that the buyer is requesting shipment of the item to an
 unconfirmed (not on file with eBay) address. This value is allowed when the
 <b>DisputeReason</b> value is <b>BuyerHasNotPaid</b> or
 <b>TransactionMutuallyCanceled</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_SHIPPING_ADDRESS_NOT_CONFIRMED;

/**
 
 This value is deprecated, and should not be used.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_PAYMENT_METHOD_NOT_SUPPORTED;

/**
 
 This value is deprecated, and should not be used.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_BUYER_NO_LONGER_REGISTERED;

/**
 
 This value can be used when no other explanation in <b>
 DisputeExplanationCodeType</b> is appropriate for the situation. This value is
 allowed when the <b>DisputeReason</b> value is
 <b>BuyerHasNotPaid</b> or
 <b>TransactionMutuallyCanceled</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_OTHER_EXPLANATION;

/**
 
 This value can be used when no other explanation in
 <b>DisputeExplanationCodeType</b> is appropriate for the situation. This
 value is allowed when the <b>DisputeReason</b> value is
 <b>ItemNotReceived</b> or <b>SignificantlyNotAsDescribed</b>.
 This value cannot be used in <b>AddDispute</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_UNSPECIFIED;

/**
 
 This value indicates that the Unpaid Item case was opened by eBay through the Unpaid
 Item Assistance mechanism. This value cannot be used in
 <b>AddDispute</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_UPI_ASSISTANCE;

/**
 
 This value indicates that the buyer has not paid the seller for the order line item,
 or has paid the seller but the payment has not cleared. This value is allowed when
 the <b>DisputeReason</b> value is <b>BuyerHasNotPaid</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_BUYER_PAYMENT_NOT_RECEIVED_OR_CLEARED;

/**
 
 This value indicates that the buyer is requesting shipment of the item to a country
 that is on the seller's ship-to exclusion list. This value is allowed when the
 <b>DisputeReason</b> value is <b>BuyerHasNotPaid</b> or
 <b>TransactionMutuallyCanceled</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_SELLER_DOESNT_SHIP_TO_COUNTRY;

/**
 
 This value indicates that the buyer has not paid for the order line item. This value
 is allowed when the <b>DisputeReason</b> value is
 <b>BuyerHasNotPaid</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_BUYER_NOT_PAID;

/**
 
 This value indicates that the Unpaid Item case was opened by eBay through the Unpaid
 Item Assistance mechanism, and then was subsequently converted to a manual dispute,
 either by the seller or by eBay. This value cannot be used in
 <b>AddDispute</b>.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_UPI_ASSISTANCE_DISABLED;

/**
 
  This value indicates that the seller ran out of stock on the item, cannot fulfill
  the order, and has to cancel the order line item. This value is allowed when the
  <b>DisputeReason</b> value is
  <b>TransactionMutuallyCanceled</b>.
     
*/
extern NSString *const Trading_DisputeExplanationCodeType_SELLER_RAN_OUT_OF_STOCK;

/**
 
 Reserved for internal or future use.
 
*/
extern NSString *const Trading_DisputeExplanationCodeType_CUSTOM_CODE;
