// Generated by xsd compiler for ios/objective-c
// DO NOT CHANGE!

#import <Foundation/Foundation.h>
#import "PicoClassSchema.h"
#import "PicoPropertySchema.h"
#import "PicoConstants.h"
#import "PicoBindable.h"
#import "Trading_AbstractRequestType.h"



/**
 
 Retrieves price changes, item revisions, description revisions,
 and other changes that have occurred within the last 48 hours
 related to a seller's eBay listings.
 
 
 @ingroup EBayAPIInterface
*/
@interface Trading_GetSellerEventsRequestType : Trading_AbstractRequestType {

@private
    NSString *_userID;
    NSDate *_startTimeFrom;
    NSDate *_startTimeTo;
    NSDate *_endTimeFrom;
    NSDate *_endTimeTo;
    NSDate *_modTimeFrom;
    NSDate *_modTimeTo;
    NSNumber *_newItemFilter;
    NSNumber *_includeWatchCount;
    NSNumber *_includeVariationSpecifics;
    NSNumber *_hideVariations;

}


/**
 
 eBay user ID for the seller whose events are to be returned.
 If not specified, retrieves events for the user identified by
 the authentication token passed in the request. Note that since user information is anonymous to everyone except the bidder and the seller (during an active auction), only sellers looking for information about
 their own listings and bidders who know the user IDs of their sellers
 will be able to make this API call successfully.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *userID;

/**
 
 Describes the earliest (oldest) time to use in a time range filter based
 on item start time. Must be specified if StartTimeTo is specified. Either
 the StartTimeFrom, EndTimeFrom, or ModTimeFrom filter must be specified.
 If you do not specify the correspoding To filter,
 it is set to the time you make the call.
 For better results, the time period you use should be less than 48 hours.
 If 3000 or more items are found, use a smaller time range.<br>
 <br>
 Include a 2-minute, overlapping buffer between requests.
 For example, if StartTimeTo was 6:58 in a prior request,
 the current request should use 6:56 in StartTimeFrom
 (e.g., use ranges like 5:56-6:58, 6:56-7:58, 7:56-8:58).
 
 
 type : NSDate, wrapper for primitive date
*/
@property (nonatomic, retain) NSDate *startTimeFrom;

/**
 
 Describes the latest (most recent) date to use in a time range filter
 based on item start time. If you specify the corresponding From filter,
 but you do not include StartTimeTo, the StartTimeTo is set to
 the time you make the call.
 
 
 type : NSDate, wrapper for primitive date
*/
@property (nonatomic, retain) NSDate *startTimeTo;

/**
 
 Describes the earliest (oldest) date to use in a time range filter based
 on item end time. Must be specified if EndTimeTo is specified. Either
 the StartTimeFrom, EndTimeFrom, or ModTimeFrom filter must be specified.
 If you do not specify the correspoding To filter,
 it is set to the time you make the call.<br>
 <br>
 For better results, the time range you use should be less than 48 hours.
 If 3000 or more items are found, use a smaller time range.<br>
 <br>
 Include a 2-minute, overlapping buffer between requests.
 For example, if EndTimeTo was 6:58 in a prior request,
 the current request should use 6:56 in EndTimeFrom
 (e.g., use ranges like 5:56-6:58, 6:56-7:58, 7:56-8:58).
 
 
 type : NSDate, wrapper for primitive date
*/
@property (nonatomic, retain) NSDate *endTimeFrom;

/**
 
 Describes the latest (most recent) date to use in a time range filter
 based on item end time. If you specify the corresponding From filter,
 but you do not include EndTimeTo, then EndTimeTo is set
 to the time you make the call.
 
 
 type : NSDate, wrapper for primitive date
*/
@property (nonatomic, retain) NSDate *endTimeTo;

/**
 
 Describes the earliest (oldest) date to use in a time range filter based
 on item modification time. Must be specified if ModTimeTo is specified. Either
 the StartTimeFrom, EndTimeFrom, or ModTimeFrom filter must be specified.
 If you do not specify the correspoding To filter,
 it is set to the time you make the call.<br>
 <br>
 Include a 2-minute, overlapping buffer between requests.
 For example, if ModTimeTo was 6:58 in a prior request,
 the current request should use 6:56 in ModTimeFrom
 (e.g., use ranges like 5:56-6:58, 6:56-7:58, 7:56-8:58).
 <br><br>
 For better results, the time range you use should be less than 48 hours.
 If 3000 or more items are found, use a smaller time range.
 <br><br>
 If an unexpected item is returned (including an old item
 or an unchanged active item), please ignore the item.
 Although a maintenance process may have triggered a change in the modification time,
 item characteristics are unchanged.
 
 
 type : NSDate, wrapper for primitive date
*/
@property (nonatomic, retain) NSDate *modTimeFrom;

/**
 
 Describes the latest (most recent) date and time to use in a time range filter
 based on the time an item's record was modified. If you specify
 the corresponding From filter, but you do not include ModTimeTo,
 then ModTimeTo is set to the time you make the call.
 Include a 2-minute buffer between the current time and
 the ModTimeTo filter.
 
 
 type : NSDate, wrapper for primitive date
*/
@property (nonatomic, retain) NSDate *modTimeTo;

/**
 
 Default is true. If true, response includes only items that have been modified
 within the ModTime range. If false, response includes all items.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *newItemFilter;

/**
 
 Specifies whether to include WatchCount in Item nodes returned. WatchCount
 is the number of watches buyers have placed on the item from their My eBay
 accounts.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *includeWatchCount;

/**
 
 Specifies whether to force the response to include
 variation specifics for multi-variation listings. <br>
 <br>
 If false (or not specified), eBay keeps the response as small as
 possible by not returning Variation.VariationSpecifics.
 It only returns Variation.SKU as an identifier
 (along with the variation price and other selling details).
 If the variation has no SKU, then Variation.VariationSpecifics
 is returned as the variation's unique identifier.<br>
 <br>
 If true, Variation.VariationSpecifics is returned.
 (Variation.SKU is also returned, if the variation has a SKU.)
 This may be useful for applications that don't track variations
 by SKU.<br>
 <br>
 Ignored when HideVariations=true.<br>
 <br>
 Please note that if the seller includes a large number of
 variations in many listings, using this flag may degrade the
 call's performance. Therefore, when you use this flag, you may
 need to reduce the total number of items you're requesting at
 once. For example, you may need to use shorter time ranges in
 the EndTime, StartTime, or ModTime filters.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *includeVariationSpecifics;

/**
 
 Specifies whether to force the response to hide
 variation details for multi-variation listings.<br>
 <br>
 If false (or not specified), eBay returns variation details (if
 any). In this case, the amount of detail can be controlled by
 using IncludeVariationSpecifics.<br>
 <br>
 If true, variation details are not returned (and
 IncludeVariationSpecifics has no effect). This may be useful for
 applications that use other calls, notifications, alerts,
 or reports to track price and quantity details.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *hideVariations;


@end
