// Generated by xsd compiler for ios/objective-c
// DO NOT CHANGE!

#import <Foundation/Foundation.h>
#import "PicoClassSchema.h"
#import "PicoPropertySchema.h"
#import "PicoConstants.h"
#import "PicoBindable.h"


@class Trading_ShipmentType;
@class Trading_VariationType;
@class Trading_AmountType;

/**
 
 Contains information about a single line item (transaction) in an order created
 through Selling Manager.
 
 
 @ingroup EBayAPIInterface
*/
@interface Trading_SellingManagerSoldTransactionType : NSObject <PicoBindable> {

@private
    NSString *_invoiceNumber;
    NSNumber *_transactionID;
    NSNumber *_saleRecordID;
    NSString *_itemID;
    NSNumber *_quantitySold;
    Trading_AmountType *_itemPrice;
    Trading_AmountType *_subtotalAmount;
    NSString *_itemTitle;
    NSString *_listingType;
    NSNumber *_relisted;
    NSNumber *_watchCount;
    Trading_AmountType *_startPrice;
    Trading_AmountType *_reservePrice;
    NSNumber *_secondChanceOfferSent;
    NSString *_customLabel;
    NSString *_soldOn;
    NSMutableArray *_listedOn;
    Trading_ShipmentType *_shipment;
    NSNumber *_charityListing;
    Trading_VariationType *_variation;
    NSString *_orderLineItemID;
    NSMutableArray *_any;

}


/**
 
 Seller's customized invoice number.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *invoiceNumber;

/**
 
 Unique identifier for an eBay order line item (transaction). An order line
 item is created once there is a commitment from a buyer to
 purchase an item. Since an auction listing can only have one order line
 item during the duration of the listing, the <b>TransactionID</b>
 for auction listings is always 0. Along with its corresponding <b>ItemID</b>, a
 <b>TransactionID</b> is used and referenced during an order checkout flow and
 after checkout has been completed.
 
 
 type : NSNumber, wrapper for primitive long
*/
@property (nonatomic, retain) NSNumber *transactionID;

/**
 
 Unique identifier for a Selling Manager sale record. This field is created
 at the same time as the order line item (transaction). A sale record is
 displayed in the Sold view in Selling Manager and contains information on
 the buyer and shipping. In the <b>GetItemTransactions</b>, <b>GetSellerTransactions</b>,
 <b>GetOrders</b>, and <b>GetOrderTransactions</b> calls, the <b>SaleRecordID</b> value is
 reflected in the <b>ShippingDetails.SellingManagerSalesRecordNumber</b> field.
 <br/><br/>
 For orders that occurred within the last 30 days, passing only the SaleRecordID into the GetSellingManagerSoldListings
 request will return the sale record. However, for sales that occurred more than 30 days ago, the SaleDateRange container
 must also be used, passing in a date range that includes the date on which the specific sale occurred.
 
 
 type : NSNumber, wrapper for primitive long
*/
@property (nonatomic, retain) NSNumber *saleRecordID;

/**
 
 Unique identifier for an eBay item listing.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *itemID;

/**
 
 Total number of identical items sold in the order line item.
 
 
 type : NSNumber, wrapper for primitive int
*/
@property (nonatomic, retain) NSNumber *quantitySold;

/**
 
 Price per item.
 
 
 type : class Trading_AmountType
*/
@property (nonatomic, retain) Trading_AmountType *itemPrice;

/**
 
 This value is calculated by multplying the <b>ItemPrice</b> value by the
 <b>QuantitySold</b> value.
 
 
 type : class Trading_AmountType
*/
@property (nonatomic, retain) Trading_AmountType *subtotalAmount;

/**
 
 The title of the item listing.
 <br><br>
 <span class="tablenote"><b>Note:</b>
 The maximum length of an eBay Item Title is increasing to 80 characters in
 Version 735.
 </span>
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *itemTitle;

/**
 
 The item listing type.
 
 
 type: string constant in Trading_ListingTypeCodeType.h
*/
@property (nonatomic, retain) NSString *listingType;

/**
 
 Boolean value indicating whether the item is a relisted item.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *relisted;

/**
 
 Number of users watching the item.
 
 
 type : NSNumber, wrapper for primitive int
*/
@property (nonatomic, retain) NSNumber *watchCount;

/**
 
 Start price of the item.
 
 
 type : class Trading_AmountType
*/
@property (nonatomic, retain) Trading_AmountType *startPrice;

/**
 
 Reserve Price of the item (if a Reserve Price was set for the item).
 
 
 type : class Trading_AmountType
*/
@property (nonatomic, retain) Trading_AmountType *reservePrice;

/**
 
 Boolean value indicating whether or not a Second Chance offer was sent by
 the seller to an eligible bidder.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *secondChanceOfferSent;

/**
 
 Custom label associated with this order line item.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *customLabel;

/**
 
 The platform on which the item was sold.
 
 
 type: string constant in Trading_TransactionPlatformCodeType.h
*/
@property (nonatomic, retain) NSString *soldOn;

/**
 
 The platform on which the item was listed.
 
 
 entry type : string constant in Trading_TransactionPlatformCodeType.h
*/

@property (nonatomic, retain) NSMutableArray *listedOn;

/**
 
 Container consisting of tracking information for the shipment.
 
 
 type : class Trading_ShipmentType
*/
@property (nonatomic, retain) Trading_ShipmentType *shipment;

/**
 
 This field is returned as True if the item is listed as a charity item.
 
 
 type : NSNumber, wrapper for primitive bool
*/
@property (nonatomic, retain) NSNumber *charityListing;

/**
 
  In a fixed-priced listing, a seller can offer variations of the same item.
  For example, the seller could create a fixed-priced listing for a t-shirt
  design and offer the shirt in different colors and sizes. In this case, each
  color and size combination is a separate variation. Each variation can have
  a different quantity and price. Due to the possible price differentiation,
  buyers can buy multiple items from this listing at the same time, but all of
  the items must be of the same variation. One order line item is created
  whether one or multiple items of the same variation are purchased.
  <br><br>
  The <b>Variation</b> node contains information about which variation was purchased.
  Therefore, applications that process order line items should always check to see
  if this node is present.
 
 
 type : class Trading_VariationType
*/
@property (nonatomic, retain) Trading_VariationType *variation;

/**
 
 A unique identifier for an eBay order line item. This field is created as
 soon as there is a commitment to buy from the seller, and its value is
 based upon the concatenation of <b>ItemID</b> and <b>TransactionID</b>, with a hyphen in
 between these two IDs.
 
 
 type : NSString, wrapper for primitive string
*/
@property (nonatomic, retain) NSString *orderLineItemID;

/**
 (public property)
 
 entry type : PicoAnyElement, wrapper for primitive anyelement
*/

@property (nonatomic, retain) NSMutableArray *any;


@end
